@@ -80,14 +80,27 @@ static const struct {
 } mime_table[] = {
 	{"jpeg", GP_MIME_JPEG},
 	{"jpg",  GP_MIME_JPEG}, 
+	{"thm",  GP_MIME_JPEG}, 
 	{"tif",  GP_MIME_TIFF},
 	{"ppm",  GP_MIME_PPM},
 	{"pgm",  GP_MIME_PGM},
+	{"ogg",  GP_MIME_OGG},
 	{"avi",  GP_MIME_AVI},
 	{"mov",  GP_MIME_QUICKTIME},
+	{"moov", GP_MIME_QUICKTIME},
+	{"qt",   GP_MIME_QUICKTIME},
+	{"qtvr", GP_MIME_QUICKTIME},
+	{"mp2",  GP_MIME_MPEG},
+	{"mp3",  GP_MIME_MPEG},
+	{"mp4",  GP_MIME_MPEG},
 	{"mpg",  GP_MIME_MPEG},
+	{"mpeg", GP_MIME_MPEG},
+	{"mpe",  GP_MIME_MPEG},
+	{"mts",  GP_MIME_AVCHD},
+	{"m2ts", GP_MIME_AVCHD},
 	{"pbm", "image/x-portable-bitmap"},
 	{"crw",  GP_MIME_CRW},
+	{"rw2",  GP_MIME_RW2},
 	{"cr2",  GP_MIME_RAW},
 	{"nef",  GP_MIME_RAW},
 	{"mrw",  GP_MIME_RAW},
@@ -101,8 +114,14 @@ static const struct {
 	{"raw",  GP_MIME_RAW},
 	{"dcr",  GP_MIME_RAW},
 	{"x3f",  GP_MIME_RAW},
+	{"srw",  GP_MIME_RAW},
+	{"gf1",  GP_MIME_RAW},
+	{"srw",  GP_MIME_RAW},
 	{"png",  GP_MIME_PNG},
 	{"wav",  GP_MIME_WAV},
+	{"3gp",  "video/3gpp"},
+	{"3g2",  "video/x-3gpp2"},
+	{"dif",  "video/dv"},
 	{NULL, NULL}
 };
 
@@ -485,13 +504,20 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	unsigned int buf_len;
 #endif /* HAVE_LIBEXIF */
 	Camera *camera = (Camera*)user_data;
+	struct stat st;
 
 	result = _get_path (camera->port, folder, filename, path, sizeof(path));
 	gp_log (GP_LOG_DEBUG, "directory/get_file_func", "%s %s",folder,filename);
 	if (result < GP_OK)
 		return result;
 	gp_log (GP_LOG_DEBUG, "directory/get_file_func", "->%s",path);
-	
+
+	if (lstat (path, &st) != 0) {
+		gp_context_error (context, _("Could not get information "
+			"about '%s' in '%s' (%m)."), filename, folder);
+		return (GP_ERROR);
+	}
+	gp_file_set_mtime (file, st.st_mtime);
 
 	switch (type) {
 	case GP_FILE_TYPE_NORMAL:
