@@ -60,6 +60,10 @@ struct {
 	{"Aries ATC-0017",      GP_DRIVER_STATUS_EXPERIMENTAL, 0x0979, 0x0227},
         {"Sakar no. 75379",     GP_DRIVER_STATUS_EXPERIMENTAL, 0x0979, 0x0227},
 	{"Sakar no. 81890",     GP_DRIVER_STATUS_EXPERIMENTAL, 0x0979, 0x0227},
+	{"Sakar Nickelodeon iCarly no. 88061", GP_DRIVER_STATUS_EXPERIMENTAL,
+							0x0979, 0x0227},
+	{"Sakar Dora the Explorer no. 88067", GP_DRIVER_STATUS_EXPERIMENTAL,
+							0x0979, 0x0227},
 	{"Sakar no. 91379",     GP_DRIVER_STATUS_EXPERIMENTAL, 0x0979, 0x0227},
 	{"Sakar no. 98379",     GP_DRIVER_STATUS_EXPERIMENTAL, 0x0979, 0x0227},
         {"Sakar Kidz-Cam no. 88379",     GP_DRIVER_STATUS_EXPERIMENTAL, 
@@ -70,6 +74,8 @@ struct {
     								0x0979, 0x0227},
 	{"Sakar Star Wars kit no. 92022", GP_DRIVER_STATUS_EXPERIMENTAL,
 							       0x0979, 0x0227},
+	{"Jazwares Star Wars no. 15256", GP_DRIVER_STATUS_EXPERIMENTAL,
+							       0x0979, 0x0227},
         {"Argus Bean Sprout",     GP_DRIVER_STATUS_EXPERIMENTAL, 
     								0x0979, 0x0227},
 	{"Global Point Clipster", GP_DRIVER_STATUS_EXPERIMENTAL,
@@ -342,6 +348,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		gp_file_set_mime_type(file, GP_MIME_RAW);
 		gp_file_set_data_and_size(file, (char *)pic_buffer , b+16 );
 		return GP_OK;
+#ifdef HAVE_LIBJPEG
 	} else if (type == GP_FILE_TYPE_PREVIEW) {
 		if (!camera->pl->can_do_capture)
 			return GP_ERROR_NOT_SUPPORTED;
@@ -373,6 +380,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		gp_file_set_mime_type(file, GP_MIME_PPM);
 		gp_file_set_data_and_size(file, (char *)pic_output,
 								outputsize);
+#endif
 	} else
 		return GP_ERROR_NOT_SUPPORTED;
 
