@@ -61,7 +61,7 @@
 
 /* PTP2_FAST_TIMEOUT: how long (in milliseconds) we should wait for
  * an URB to come back on an interrupt endpoint */
-#define PTP2_FAST_TIMEOUT       50
+#define PTP2_FAST_TIMEOUT       100
 
 /* Pack / unpack functions */
 
@@ -493,7 +493,7 @@ ptp_usb_event (PTPParams* params, PTPContainer* event, int wait)
 	Camera			*camera = ((PTPData *)params->data)->camera;
 
 	if (params->deviceinfo.VendorExtensionID == PTP_VENDOR_CANON)
-		fasttimeout = PTP2_FAST_TIMEOUT*4;
+		fasttimeout = PTP2_FAST_TIMEOUT*2;
 	else
 		fasttimeout = PTP2_FAST_TIMEOUT;
 
@@ -523,6 +523,10 @@ ptp_usb_event (PTPParams* params, PTPContainer* event, int wait)
 			return PTP_ERROR_TIMEOUT;
 		return PTP_ERROR_IO;
 	}
+	if (result == 0) {
+		gp_log (GP_LOG_DEBUG, "ptp2/usb_event", "reading event an 0 read occurred, assuming timeout.");
+		return PTP_ERROR_TIMEOUT;
+	}
 	rlen = result;
 	if (rlen < 8) {
 		gp_log (GP_LOG_ERROR, "ptp2/usb_event",
