@@ -209,6 +209,12 @@ gp_filesystem_get_exif_mtime (CameraFilesystem *fs, const char *folder,
 	if (!fs)
 		return 0;
 
+	/* This is only useful for JPEGs. Avoid querying it for other types. */
+	if (	!strstr(filename,"jpg")  && !strstr(filename,"JPG") &&
+		!strstr(filename,"jpeg") && !strstr(filename,"JPEG")
+	)
+		return 0;
+
 	gp_file_new (&file);
 	if (gp_filesystem_get_file (fs, folder, filename,
 				GP_FILE_TYPE_EXIF, file, NULL) != GP_OK) {
@@ -308,7 +314,7 @@ delete_all_files (CameraFilesystem *fs, CameraFilesystemFolder *folder)
 	CameraFilesystemFile	*file;
 
 	CHECK_NULL (folder);
-	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Delete all files in folder %p", folder);
+	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Delete all files in folder %p/%s", folder, folder->name);
 
 	file = folder->files;
 	while (file) {
@@ -354,7 +360,7 @@ delete_folder (CameraFilesystem *fs, CameraFilesystemFolder **folder)
 	CameraFilesystemFolder *next;
 	CHECK_NULL (folder);
 
-	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Delete one folder %p", *folder);
+	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Delete one folder %p/%s", *folder, (*folder)->name);
 	next = (*folder)->next;
 	delete_all_files (fs, *folder);
 	free ((*folder)->name);
@@ -477,7 +483,7 @@ static int
 recurse_delete_folder (CameraFilesystem *fs, CameraFilesystemFolder *folder) {
 	CameraFilesystemFolder  **f;
 
-	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Recurse delete folder %p", folder);
+	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Recurse delete folder %p/%s", folder, folder->name);
 	f = &folder->folders;
 	while (*f) {
 		recurse_delete_folder (fs, *f);
@@ -534,7 +540,7 @@ append_to_folder (CameraFilesystemFolder *folder,
 	CameraFilesystemFolder	*f;
 	char	*s;
 
-	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Append to folder %p - %s", folder, foldername);
+	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Append to folder %p/%s - %s", folder, folder->name, foldername);
 	/* Handle multiple slashes, and slashes at the end */
 	while (foldername[0]=='/')
 		foldername++;
@@ -711,12 +717,41 @@ gp_filesystem_free (CameraFilesystem *fs)
  *
  * \return a gphoto2 error code.
  **/
+static int
+internal_append (CameraFilesystem *fs, CameraFilesystemFolder *f,
+		      const char *filename, GPContext *context)
+{
+	CameraFilesystemFile **new;
+
+	CHECK_NULL (fs && f);
+
+	gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Internal append %s to folder %s", filename, f->name);
+	/* Check folder for existence, if not, create it. */
+	new = &f->files;
+	while (*new) {
+		if (!strcmp((*new)->name, filename)) break;
+		new = &((*new)->next);
+	}
+	if (*new)
+		return (GP_ERROR_FILE_EXISTS);
+
+	CHECK_MEM ((*new) = calloc (sizeof (CameraFilesystemFile), 1))
+	(*new)->name = strdup (filename);
+	if (!(*new)->name) {
+		free (*new);
+		*new = NULL;
+		return (GP_ERROR_NO_MEMORY);
+	}
+	(*new)->info_dirty = 1;
+	return (GP_OK);
+}
+
 int
 gp_filesystem_append (CameraFilesystem *fs, const char *folder,
 		      const char *filename, GPContext *context)
 {
-	CameraFilesystemFile **new;
 	CameraFilesystemFolder *f;
+	int ret;
 
 	CHECK_NULL (fs && folder);
 	CC (context);
@@ -727,31 +762,23 @@ gp_filesystem_append (CameraFilesystem *fs, const char *folder,
 	f = lookup_folder (fs, fs->rootfolder, folder, context);
 	if (!f)
 		CR (append_folder (fs, folder, &f, context));
+	if (f->files_dirty) { /* Need to load folder from driver first ... capture case */
+		CameraList	*xlist;
+		int ret;
 
-	new = &f->files;
-	while (*new) {
-		if (!strcmp((*new)->name, filename)) break;
-		new = &((*new)->next);
+		ret = gp_list_new (&xlist);
+		if (ret != GP_OK) return ret;
+		ret = gp_filesystem_list_files (fs, folder, xlist, context);
+		gp_list_free (xlist);
+		if (ret != GP_OK) return ret;
 	}
-	if (*new) {
-		gp_context_error (context,
-			_("Could not append '%s' to folder '%s' because "
-			  "this file already exists."), filename, folder);
-		return (GP_ERROR_FILE_EXISTS);
-	}
-
-	CHECK_MEM ((*new) = calloc (sizeof (CameraFilesystemFile), 1))
-	(*new)->name = strdup (filename);
-	if (!(*new)->name) {
-		free (*new);
-		*new = NULL;
-		return (GP_ERROR_NO_MEMORY);
-	}
-	(*new)->info_dirty = 1;
-	f->files_dirty = 0;
-	return (GP_OK);
+	ret = internal_append (fs, f, filename, context);
+	if (ret == GP_ERROR_FILE_EXISTS) /* not an error here ... just in case we add files twice to the list */
+		ret = GP_OK;
+	return ret;
 }
 
+
 static void
 recursive_fs_dump (CameraFilesystemFolder *folder, int depth) {
 	CameraFilesystemFolder	*f;
@@ -951,6 +978,9 @@ gp_filesystem_list_files (CameraFilesystem *fs, const char *folder,
 		gp_log (GP_LOG_DEBUG, "gphoto2-filesystem",
 			"Querying folder %s...", folder);
 		CR (delete_all_files (fs, f));
+
+		/* set it to non-dirty now, so we do not recurse via _append. */
+		f->files_dirty = 0;
 		CR (fs->file_list_func (fs, folder, list,
 					fs->list_data, context));
 
@@ -959,7 +989,7 @@ gp_filesystem_list_files (CameraFilesystem *fs, const char *folder,
 			CR (gp_list_get_name (list, y, &name));
 			gp_log (GP_LOG_DEBUG, "gphoto2-filesystem",
 					 "Added '%s'", name);
-			CR (gp_filesystem_append (fs, folder, name, context));
+			CR (internal_append (fs, f, name, context));
 		}
 		gp_list_reset (list);
 	}
@@ -1211,6 +1241,23 @@ gp_filesystem_remove_dir (CameraFilesystem *fs, const char *folder,
 	 */
 	f = lookup_folder (fs, fs->rootfolder, folder, context);
 	if (!f) return (GP_ERROR_DIRECTORY_NOT_FOUND);
+	/* Check if we need to load the folder ... */
+	if (f->folders_dirty) {
+		CameraList	*list;
+		int		ret;
+		/*
+		 * The owning folder is dirty. List the folders in it 
+		 * to make it clean.
+		 */
+		gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Folder %s is dirty. "
+			"Listing folders in there to make folder clean...", folder);
+		ret = gp_list_new (&list);
+		if (ret == GP_OK) {
+			ret = gp_filesystem_list_folders (fs, folder, list, context);
+			gp_list_free (list);
+			gp_log (GP_LOG_DEBUG, "gphoto2-filesystem", "Done making folder %s clean...", folder);
+		}
+	}
 	prev = &(f->folders);
 	while (*prev) {
 		if (!strcmp (name, (*prev)->name))
@@ -1469,10 +1516,9 @@ recursive_folder_scan (
  **/
 int
 gp_filesystem_get_folder (CameraFilesystem *fs, const char *filename,
-			  const char **folder, GPContext *context)
+			  char **folder, GPContext *context)
 {
 	int ret;
-
 	CHECK_NULL (fs && filename && folder);
 	CC (context);
 
@@ -1652,8 +1698,11 @@ gp_filesystem_get_file_impl (CameraFilesystem *fs, const char *folder,
 	CR (gp_file_set_type (file, type));
 	CR (gp_file_set_name (file, filename));
 
+#if 0
+	/* this disables LRU completely. */
 	/* Cache this file */
 	CR (gp_filesystem_set_file_noop (fs, folder, file, context));
+#endif
 
 	/*
 	 * Often, thumbnails are of a different mime type than the normal
