@@ -414,7 +414,7 @@ gp_port_usb_check_int (GPPort *port, char *bytes, int size, int timeout)
 	ret = usb_interrupt_read(port->pl->dh, port->settings.usb.intep,
 			     bytes, size, timeout);
         if (ret < 0) {
-		if (errno == EAGAIN)
+		if ((errno == EAGAIN) || (errno == ETIMEDOUT))
 			return GP_ERROR_TIMEOUT;
 		return GP_ERROR_IO_READ;
 	}
@@ -530,9 +530,11 @@ gp_port_usb_update (GPPort *port)
 	if (!port)
 		return GP_ERROR_BAD_PARAMETERS;
 
+#if 0
 	if (port->pl->interface == -1) port->pl->interface = port->settings.usb.interface;
 	if (port->pl->config == -1) port->pl->config = port->settings.usb.config;
 	if (port->pl->altsetting == -1) port->pl->altsetting = port->settings.usb.altsetting;
+#endif
 
 	/* The portname can also be changed with the device still fully closed. */
 	memcpy(&port->settings.usb.port, &port->settings_pending.usb.port,
@@ -805,7 +807,7 @@ static int
 gp_port_usb_match_mtp_device(struct usb_device *dev,int *configno, int *interfaceno, int *altsettingno)
 {
 	char buf[1000], cmd;
-	int ret,i,i1,i2;
+	int ret,i,i1,i2, xifaces,xnocamifaces;
 	usb_dev_handle *devh;
 
 	/* All of them are "vendor specific" device class */
@@ -813,7 +815,36 @@ gp_port_usb_match_mtp_device(struct usb_device *dev,int *configno, int *interfac
 	if ((dev->descriptor.bDeviceClass!=0xff) && (dev->descriptor.bDeviceClass!=0))
 		return 0;
 #endif
+	if (dev->config) {
+		xifaces = xnocamifaces = 0;
+		for (i = 0; i < dev->descriptor.bNumConfigurations; i++) {
+			unsigned int j;
 
+			for (j = 0; j < dev->config[i].bNumInterfaces; j++) {
+				int k;
+				xifaces++;
+
+				for (k = 0; k < dev->config[i].interface[j].num_altsetting; k++) {
+					struct usb_interface_descriptor *intf = &dev->config[i].interface[j].altsetting[k]; 
+					if (	(intf->bInterfaceClass == USB_CLASS_HID)	||
+						(intf->bInterfaceClass == USB_CLASS_PRINTER)	||
+						(intf->bInterfaceClass == USB_CLASS_AUDIO)	||
+						(intf->bInterfaceClass == USB_CLASS_HUB)	||
+						(intf->bInterfaceClass == USB_CLASS_COMM)	||
+						(intf->bInterfaceClass == 0xe0)	/* wireless/bluetooth*/
+					)
+						xnocamifaces++;
+				}
+			}
+		}
+	}
+	if (xifaces == xnocamifaces) /* only non-camera ifaces */
+		return 0;
+
+	/* Marcus: Avoid this probing altogether, its too unstable on some devices */
+	return 0;
+
+#if 0
 	devh = usb_open (dev);
 	if (!devh)
 		return 0;
@@ -910,6 +941,7 @@ found:
 errout:
 	usb_close (devh);
 	return 0;
+#endif
 }
 
 static int
@@ -1004,6 +1036,10 @@ gp_port_usb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 
 			if ((devname[0] != '\0') && strcmp(devname, dev->filename))
 				continue;
+			gp_log (GP_LOG_VERBOSE, "gphoto2-port-usb",
+				"Looking for USB device "
+				"(class 0x%x, subclass, 0x%x, protocol 0x%x)...", 
+				class, subclass, protocol);
 
 			ret = gp_port_usb_match_device_by_class(dev, class, subclass, protocol, &config, &interface, &altsetting);
 			if (!ret)
@@ -1011,8 +1047,8 @@ gp_port_usb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 
 			port->pl->d = dev;
 			gp_log (GP_LOG_VERBOSE, "gphoto2-port-usb",
-				"Looking for USB device "
-				"(class 0x%x, subclass, 0x%x, protocol 0x%x)... found.", 
+				"Found USB class device "
+				"(class 0x%x, subclass, 0x%x, protocol 0x%x).", 
 				class, subclass, protocol);
 			/* Set the defaults */
 			if (dev->config) {
